@@ -35,7 +35,6 @@
 #include "dooble_application.h"
 #include "dooble_charts.h"
 #include "dooble_downloads.h"
-#include "dooble_page.h"
 #include "dooble_tab_bar.h"
 #include "dooble_tab_widget.h"
 #include "dooble_ui_utilities.h"
@@ -52,7 +51,7 @@ dooble_tab_bar::dooble_tab_bar(QWidget *parent):QTabBar(parent)
      "QToolButton::menu-button {border: none;}");
 #else
   m_next_tool_button->setStyleSheet
-    ("QToolButton {margin-bottom: 1px; margin-top: 1px;}"
+    ("QToolButton {margin-bottom: 10px; margin-top: 10px;}"
      "QToolButton::menu-button {border: none;}");
 #endif
   m_previous_tool_button = new QToolButton(nullptr);
@@ -64,7 +63,7 @@ dooble_tab_bar::dooble_tab_bar(QWidget *parent):QTabBar(parent)
      "QToolButton::menu-button {border: none;}");
 #else
   m_previous_tool_button->setStyleSheet
-    ("QToolButton {margin-bottom: 1px; margin-top: 1px;}"
+    ("QToolButton {margin-bottom: 10px; margin-top: 10px;}"
      "QToolButton::menu-button {border: none;}");
 #endif
 
@@ -149,10 +148,14 @@ QSize dooble_tab_bar::tabSizeHint(int index) const
 {
   auto const tab_position
     (dooble_settings::setting("tab_position").toString().trimmed());
+  auto page = this->page(index);
   auto size(QTabBar::tabSizeHint(index));
 
   if(tab_position == "east" || tab_position == "west")
     {
+      if(page && page->is_pinned())
+	return size;
+
       auto const f = qFloor(static_cast<double> (rect().height()) /
 			    static_cast<double> (qMax(1, count())));
       static const int maximum_tab_height = 225;
@@ -172,6 +175,9 @@ QSize dooble_tab_bar::tabSizeHint(int index) const
     }
   else
     {
+      if(page && page->is_pinned())
+	return size;
+
       auto const f = qFloor(static_cast<double> (rect().width()) /
 			    static_cast<double> (qMax(1, count())));
       static const int maximum_tab_width = 225;
@@ -224,6 +230,16 @@ bool dooble_tab_bar::is_private(void) const
   return false;
 }
 
+dooble_page *dooble_tab_bar::page(int index) const
+{
+  auto tab_widget = qobject_cast<dooble_tab_widget *> (parentWidget());
+
+  if(tab_widget)
+    return qobject_cast<dooble_page *> (tab_widget->widget(index));
+
+  return nullptr;
+}
+
 void dooble_tab_bar::hideEvent(QHideEvent *event)
 {
   QTabBar::hideEvent(event);
@@ -512,6 +528,15 @@ void dooble_tab_bar::slot_next_tab(void)
       m_next_tool_button->setEnabled(tool_button->isEnabled());
 }
 
+void dooble_tab_bar::slot_open_tab_as_new_cute_window(void)
+{
+  auto action = qobject_cast<QAction *> (sender());
+
+  if(action)
+    emit open_tab_as_new_cute_window
+      (tabAt(action->property("point").toPoint()));
+}
+
 void dooble_tab_bar::slot_open_tab_as_new_private_window(void)
 {
   auto action = qobject_cast<QAction *> (sender());
@@ -529,6 +554,15 @@ void dooble_tab_bar::slot_open_tab_as_new_window(void)
     emit open_tab_as_new_window(tabAt(action->property("point").toPoint()));
 }
 
+void dooble_tab_bar::slot_pin_tab(void)
+{
+  auto action = qobject_cast<QAction *> (sender());
+
+  if(action)
+    emit pin_tab
+      (action->isChecked(), tabAt(action->property("point").toPoint()));
+}
+
 void dooble_tab_bar::slot_previous_tab(void)
 {
   int i = 0;
@@ -591,11 +625,22 @@ void dooble_tab_bar::slot_show_context_menu(const QPoint &point)
   action->setProperty("point", point);
   menu.addSeparator();
 
+  auto open_as_new_cute_window_action = menu.addAction
+    (QIcon::fromTheme(use_material_icons + "view-private",
+		      QIcon(QString(":/%1/48/new_window.png").
+			    arg(icon_set))),
+     tr("Open As New Cute Window..."),
+     this,
+     SLOT(slot_open_tab_as_new_cute_window(void)));
+
+  open_as_new_cute_window_action->setEnabled(false);
+  open_as_new_cute_window_action->setProperty("point", point);
+
   auto open_as_new_private_window_action = menu.addAction
     (QIcon::fromTheme(use_material_icons + "view-private",
 		      QIcon(QString(":/%1/48/new_private_window.png").
 			    arg(icon_set))),
-     tr("Open as New P&rivate Window..."),
+     tr("Open As New P&rivate Window..."),
      this,
      SLOT(slot_open_tab_as_new_private_window(void)));
 
@@ -605,7 +650,7 @@ void dooble_tab_bar::slot_show_context_menu(const QPoint &point)
   auto open_as_new_window_action = menu.addAction
     (QIcon::fromTheme(use_material_icons + "window-new",
 		      QIcon(QString(":/%1/48/new_window.png").arg(icon_set))),
-     tr("Open as &New Window..."),
+     tr("Open As &New Window..."),
      this,
      SLOT(slot_open_tab_as_new_window(void)));
 
@@ -730,6 +775,8 @@ void dooble_tab_bar::slot_show_context_menu(const QPoint &point)
 		  SLOT(slot_go_forward(void)));
 	  javascript_action->setCheckable(true);
 	  javascript_action->setEnabled(tab_at > -1);
+	  open_as_new_cute_window_action->setEnabled
+	    (count() > 1 && tab_at > -1);
 	  open_as_new_private_window_action->setEnabled
 	    (count() > 1 && tab_at > -1);
 	  open_as_new_window_action->setEnabled
@@ -836,6 +883,13 @@ void dooble_tab_bar::slot_show_context_menu(const QPoint &point)
 			  SLOT(slot_clone_tab(void)));
   action->setEnabled(page);
   action->setProperty("point", point);
+  action = menu.addAction(tr("Pin Tab"),
+			  this,
+			  SLOT(slot_pin_tab(void)));
+  action->setCheckable(true);
+  action->setChecked(page && page->is_pinned());
+  action->setEnabled(page);
+  action->setProperty("point", point);
 
   foreach(auto action, menu.actions())
     if(action != lock_action)
